@@ -455,7 +455,7 @@ GRalgo <- function(contrast, W, seed, sigma_max, range, breaks, step, operator,
                          "# new GR points", 
                          "newGR <- setdiff(GR, GRsave)", 
                          "if(length(newGR) > 0){", 
-                         "front <- as.factor(calcGroupsW_cpp(W, newGR - 1, 10000)$group_subset) \n", 
+                         "front <- as.factor(calcGroupsW_cpp(W_i = W@i, W_p = W@p, newGR - 1, 10000)$group_subset) \n", 
                          "# order front by ", 
                          "levels(front) <- levels(front)[rank(-table(front) + seq(0, 0.1, length.out = length(levels(front))))]", 
                          "front <- as.numeric(as.character(front))", 
